PyXMake Developer Guide: PyXMake.VTL.portainer Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.portainer Namespace Reference

## Functions
| main (token=None, **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake.
    Technically, this script runs w/o PyXMake, but the default pipeline refers to the project.

    @note: Execute a docker command via the Portainer API remotely from any system.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - Portainer X-API-Token

    @date:
          - 16.01.2021

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.portainer.main | ( |  | token = None,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 26 of file portainer.py.